@@ -2,7 +2,7 @@
 #
 # Authors: Tom Kralidis <tomkralidis@gmail.com>
 #
-# Copyright (c) 2020 Tom Kralidis
+# Copyright (c) 2021 Tom Kralidis
 #
 # Permission is hereby granted, free of charge, to any person
 # obtaining a copy of this software and associated documentation
@@ -28,7 +28,9 @@
 # =================================================================
 
 from collections import OrderedDict
+import json
 import logging
+from urllib.parse import urlparse
 
 from elasticsearch import Elasticsearch, exceptions, helpers
 from elasticsearch.client.indices import IndicesClient
@@ -49,23 +51,44 @@ class ElasticsearchProvider(BaseProvider):
 
         :param provider_def: provider definition
 
-        :returns: pygeoapi.providers.elasticsearch_.ElasticsearchProvider
+        :returns: pygeoapi.provider.elasticsearch_.ElasticsearchProvider
         """
 
-        BaseProvider.__init__(self, provider_def)
+        super().__init__(provider_def)
 
-        url_tokens = self.data.split('/')
+        self.es_host, self.index_name = self.data.rsplit('/', 1)
 
         LOGGER.debug('Setting Elasticsearch properties')
-        self.es_host = url_tokens[2]
-        self.index_name = url_tokens[-1]
         self.is_gdal = False
 
         LOGGER.debug('host: {}'.format(self.es_host))
         LOGGER.debug('index: {}'.format(self.index_name))
 
+        self.type_name = 'FeatureCollection'
+        self.url_parsed = urlparse(self.es_host)
+
         LOGGER.debug('Connecting to Elasticsearch')
-        self.es = Elasticsearch(self.es_host)
+
+        if self.url_parsed.port is None:  # proxy to default HTTP(S) port
+            if self.url_parsed.scheme == 'https':
+                port = 443
+            else:
+                port = 80
+        else:  # was set explictly
+            port = self.url_parsed.port
+
+        url_settings = {
+            'scheme': self.url_parsed.scheme,
+            'host': self.url_parsed.hostname,
+            'port': port
+        }
+
+        if self.url_parsed.path:
+            url_settings['url_prefix'] = self.url_parsed.path
+
+        LOGGER.debug('URL settings: {}'.format(url_settings))
+        LOGGER.debug('Connecting to Elasticsearch')
+        self.es = Elasticsearch([url_settings])
         if not self.es.ping():
             msg = 'Cannot connect to Elasticsearch'
             LOGGER.error(msg)
@@ -97,7 +120,12 @@ class ElasticsearchProvider(BaseProvider):
         ii = ic.get(self.index_name)
 
         try:
-            p = ii[self.index_name]['mappings']['properties']['properties']  # noqa
+            if '*' not in self.index_name:
+                p = ii[self.index_name]['mappings']['properties']['properties']
+            else:
+                LOGGER.debug('Wildcard index; setting from first match')
+                index_name_ = list(ii.keys())[0]
+                p = ii[index_name_]['mappings']['properties']['properties']
         except KeyError:
             LOGGER.debug('ES index looks generated by GDAL')
             self.is_gdal = True
@@ -109,12 +137,14 @@ class ElasticsearchProvider(BaseProvider):
                     type_ = 'string'
                 else:
                     type_ = v['type']
-                fields_[k] = type_
+
+                fields_[k] = {'type': type_}
 
         return fields_
 
     def query(self, startindex=0, limit=10, resulttype='results',
-              bbox=[], datetime=None, properties=[], sortby=[]):
+              bbox=[], datetime_=None, properties=[], sortby=[],
+              select_properties=[], skip_geometry=False, q=None):
         """
         query Elasticsearch index
 
@@ -122,9 +152,12 @@ class ElasticsearchProvider(BaseProvider):
         :param limit: number of records to return (default 10)
         :param resulttype: return results or hit limit (default results)
         :param bbox: bounding box [minx,miny,maxx,maxy]
-        :param datetime: temporal (datestamp or extent)
+        :param datetime_: temporal (datestamp or extent)
         :param properties: list of tuples (name, value)
         :param sortby: list of dicts (property, order)
+        :param select_properties: list of property names
+        :param skip_geometry: bool of whether to skip geometry (default False)
+        :param q: full-text search term(s)
 
         :returns: dict of 0..n GeoJSON features
         """
@@ -158,7 +191,7 @@ class ElasticsearchProvider(BaseProvider):
 
             query['query']['bool']['filter'].append(bbox_filter)
 
-        if datetime is not None:
+        if datetime_ is not None:
             LOGGER.debug('processing datetime parameter')
             if self.time_field is None:
                 LOGGER.error('time_field not enabled for collection')
@@ -166,9 +199,9 @@ class ElasticsearchProvider(BaseProvider):
 
             time_field = self.mask_prop(self.time_field)
 
-            if '/' in datetime:  # envelope
+            if '/' in datetime_:  # envelope
                 LOGGER.debug('detected time range')
-                time_begin, time_end = datetime.split('/')
+                time_begin, time_end = datetime_.split('/')
 
                 range_ = {
                     'range': {
@@ -187,10 +220,10 @@ class ElasticsearchProvider(BaseProvider):
 
             else:  # time instant
                 LOGGER.debug('detected time instant')
-                filter_.append({'match': {time_field: datetime}})
+                filter_.append({'match': {time_field: datetime_}})
 
             LOGGER.debug(filter_)
-            query['query']['bool']['filter'].append(filter_)
+            query['query']['bool']['filter'].append(*filter_)
 
         if properties:
             LOGGER.debug('processing properties')
@@ -210,14 +243,14 @@ class ElasticsearchProvider(BaseProvider):
 
                 sp = sort['property']
 
-                if self.fields[sp] == 'string':
+                if self.fields[sp]['type'] == 'string':
                     LOGGER.debug('setting ES .raw on property')
                     sort_property = '{}.raw'.format(self.mask_prop(sp))
                 else:
                     sort_property = self.mask_prop(sp)
 
                 sort_order = 'asc'
-                if sort['order'] == 'D':
+                if sort['order'] == '-':
                     sort_order = 'desc'
 
                 sort_ = {
@@ -227,17 +260,38 @@ class ElasticsearchProvider(BaseProvider):
                 }
                 query['sort'].append(sort_)
 
-        if self.properties:
+        if q is not None:
+            LOGGER.debug('Adding free-text search')
+            query['query']['bool']['must'] = {'query_string': {'query': q}}
+
+            query['_source'] = {
+                'excludes': [
+                    'properties._metadata-payload',
+                    'properties._metadata-schema',
+                    'properties._metadata-format'
+                ]
+            }
+
+        if self.properties or select_properties:
             LOGGER.debug('including specified fields: {}'.format(
                 self.properties))
             query['_source'] = {
-                'includes': list(map(self.mask_prop, self.properties))
+                'includes': list(map(self.mask_prop,
+                                 set(self.properties) | set(select_properties)))  # noqa
             }
             query['_source']['includes'].append(self.mask_prop(self.id_field))
             query['_source']['includes'].append('type')
             query['_source']['includes'].append('geometry')
+        if skip_geometry:
+            LOGGER.debug('limiting to specified fields: {}'.format(
+                select_properties))
+            try:
+                query['_source']['excludes'] = ['geometry']
+            except KeyError:
+                query['_source'] = {'excludes': ['geometry']}
         try:
             LOGGER.debug('querying Elasticsearch')
+            LOGGER.debug(json.dumps(query, indent=4))
 
             LOGGER.debug('Setting ES paging zero-based')
             if startindex > 0:
@@ -313,7 +367,7 @@ class ElasticsearchProvider(BaseProvider):
                     'bool': {
                         'filter': [{
                             'match': {
-                                self.id_field: identifier
+                                self.mask_prop(self.id_field): identifier
                             }
                         }]
                     }
@@ -350,7 +404,7 @@ class ElasticsearchProvider(BaseProvider):
             if 'type' not in doc['_source']:
                 feature_['id'] = id_
                 feature_['type'] = 'Feature'
-            feature_['geometry'] = doc['_source']['geometry']
+            feature_['geometry'] = doc['_source'].get('geometry')
             feature_['properties'] = {}
             for key, value in doc['_source'].items():
                 if key == 'geometry':
@@ -361,12 +415,13 @@ class ElasticsearchProvider(BaseProvider):
             feature_ = doc['_source']
             id_ = doc['_source']['properties'][self.id_field]
             feature_['id'] = id_
+            feature_['geometry'] = doc['_source'].get('geometry')
 
         if self.properties:
             feature_thinned = {
                 'id': id_,
                 'type': feature_['type'],
-                'geometry': feature_['geometry'],
+                'geometry': feature_.get('geometry'),
                 'properties': OrderedDict()
             }
             for p in self.properties:
@@ -397,3 +452,42 @@ class ElasticsearchProvider(BaseProvider):
 
     def __repr__(self):
         return '<ElasticsearchProvider> {}'.format(self.data)
+
+
+class ElasticsearchCatalogueProvider(ElasticsearchProvider):
+    """Elasticsearch Provider"""
+
+    def __init__(self, provider_def):
+        super().__init__(provider_def)
+
+    def _excludes(self):
+        return [
+            'properties._metadata-anytext'
+        ]
+
+    def get_fields(self):
+        fields = super().get_fields()
+        for i in self._excludes():
+            del fields[i]
+
+        fields['q'] = {'type': 'string'}
+
+        return fields
+
+    def query(self, startindex=0, limit=10, resulttype='results',
+              bbox=[], datetime_=None, properties=[], sortby=[],
+              select_properties=[], skip_geometry=False, q=None):
+
+        records = super().query(
+            startindex=startindex, limit=limit,
+            resulttype=resulttype, bbox=bbox,
+            datetime_=datetime_, properties=properties,
+            sortby=sortby,
+            select_properties=select_properties,
+            skip_geometry=skip_geometry,
+            q=q)
+
+        return records
+
+    def __repr__(self):
+        return '<ElasticsearchCatalogueProvider> {}'.format(self.data)
